---
title: Boolean
slug: Glossary/Boolean
tags:
  - Boolean
  - CodingScripting
  - Glossary
  - JavaScript
  - Programming Languages
  - data types
---
In computer science, a **Boolean** is a logical data type that can have only the values `true` or `false`.

For example, in JavaScript, Boolean conditionals are often used to decide which sections of code to execute (such as in [if statements](/en-US/docs/Web/JavaScript/Reference/Statements/if...else)) or repeat (such as in [for loops](/en-US/docs/Web/JavaScript/Reference/Statements/for)).

Below is some JavaScript pseudocode (it's not truly executable code) demonstrating this concept.

```js
/* JavaScript if statement */
if (boolean conditional) {
   // code to execute if the conditional is true
}

if (boolean conditional) {
  console.log("boolean conditional resolved to true");
} else {
  console.log("boolean conditional resolved to false");
}

/* JavaScript for loop */
for (control variable; boolean conditional; counter) {
  // code to execute repeatedly if the conditional is true
}

for (var i=0; i < 4; i++) {
  console.log("I print only when the boolean conditional is true");
}
```

The Boolean value is named after English mathematician {{interwiki("wikipedia", "George Boole")}}, who pioneered the field of mathematical logic.

## See also

- {{Interwiki("wikipedia", "Boolean data type", "Boolean")}} on Wikipedia
- The JavaScript global object: {{jsxref("Boolean")}}
- [JavaScript data types and data structures](/en-US/docs/Web/JavaScript/Data_structures)
