---
title: Criteria for inclusion
slug: Related/Criteria_for_inclusion
tags:
  - Related
  - criteria
---
This document outlines the criteria for inclusion that a technology must pass before we will consider it for inclusion in the MDN Web Docs [Web-related technologies](/en-US/docs/Related) section. The aim here is to provide a guide you can follow to quickly work out if a non-web standards technology is suitable for inclusion.

## Web standards technologies

The MDN Web Docs remit is to document web standards technologies, or more specifically technologies that follow our standard guidelines of [when to document new technologies](/en-US/docs/MDN/Guidelines/Conventions_definitions#when_to_document_new_technologies) — the short version of this is that we document technologies on MDN Web Docs when they are specified in a specification published by a reliable standards body, and are supported in at least one browser.

These criteria signify enough interest, stability, and intent to implement by the web industry at large that we think they are a safe bet to document without wasting our time. Any earlier than that, and they may be cancelled due to lack of interest, or be so unstable that they will change significantly, meaning lots of rewriting (which we try to avoid where possible).

## Non-web standards technologies

Non-web standards technologies are technologies that do not follow our criteria summarized above. We would not normally consider them for documentation on MDN. However, there are many technologies that are not web standards, but are useful and interesting to web developers — think about developer tools, libraries, and frameworks as some of the more obvious examples.

Our mission statement is _"to provide developers with the information they need to easily build projects on the open Web"_. This suggests that we should consider documenting technologies that are useful to web developers, even if they are not open web standards, on the standards track, etc. Hence the creation of the Web-related technologies section as a place to house such documentation.

We want to maintain a certain level of quality on MDN, and not just open our doors to accept any documentation. To do so would make MDN Web Docs a messy place, and potentially harm the web industry by creation substandard, conflicting documentation.

Therefore, if you want to consider a non-web standard technology for inclusion in this section of MDN Web Docs, you should make sure that it matches the below criteria.

## The criteria

To be applicable for consideration, technologies should...

### Be open and not proprietary

At Mozilla we are supporters of open technologies, and don't wish to support closed technology ecosystems that are controlled by a single entity, not open for contributions by any interested party, and not interoperable across multiple platforms and systems. We believe that technology works better for humans when created out in the open.

### Be web-exposed in some way / related to web technologies

Our central remit is web standards technologies; there is no point starting to document technologies that do not relate to the web, or hold any interest to web developers.

### Show signs of interest and adoption

We don't want to waste our time and energy helping to document a technology that has no signals of interest and adoption from industry. It may just be that it is too early to start documenting the technology, and we could consider it in the future.

### Not be showing signs of being deprecated, or superseded

Related to the above point, we also don't want to waste our time helping to document something that is late in its lifecycle, and already showing signs of decline in interest.

### Not have an established documentation resource elsewhere

There are many libraries and frameworks in existence, which are not web standards, but are built on top of web technologies and very popular in the web industry. We do not document any of these because in general they all have established documentation resources already. It would be foolish to compete with the official resource of a popular framework — to do so would be a waste of time and probably end up confusing developers trying to learn the technology.

### Have a community willing to write and maintain the docs

The MDN Web Docs team concentrates on documenting the open web platform, and does not have time to spend on other documentation resources outside this remit. Therefore if you want a technology to be considered for documentation in this area of MDN Web Docs, you'll need to have a community assembled that is willing to write the documentation and maintain it after completion. Our team is happy to provide guidance in such cases, including edits and feedback, but we don't have time for much more than that.

## Next steps

If your chosen technology looks to meet the criteria, the next step is to propose it to the MDN team. See the [Process for selection](/en-US/docs/Related/Process_for_selection).
