---
title: 'ARIA: section role'
slug: Web/Accessibility/ARIA/Roles/section_role
tags: 
  - Accessibility
  - ARIA
  - roles
  - Reference
  - ARIA roles
---

The **`section` role**, an abstract role, is superclass role for renderable structural containment components.

> **Note:**  The `section` role is an [abstract role](/en-US/docs/Web/Accessibility/ARIA/Roles/#Abstract_roles). It is included here for completeness of documentation. It **should not be used** by web authors.

## Description

The structural `section` role is an abstract role for categorizing all the section subclass roles. The role must not be used. Some subclasses, like [`alert`](/en-US/docs/Web/Accessibility/ARIA/Roles/alert_role),
[`note`](/en-US/docs/Web/Accessibility/ARIA/Roles/note_role), and [`tooltip`](/en-US/docs/Web/Accessibility/ARIA/Roles/tooltip_role), are useful, and can be used to add semantics when no semantic HTML elements quite fits the purpose of a component. Others, like [`code`](/en-US/docs/Web/Accessibility/ARIA/Roles/code_role), [`figure`](/en-US/docs/Web/Accessibility/ARIA/Roles/figure_role), and [`subscript`](/en-US/docs/Web/Accessibility/ARIA/Roles/subscript_role), aren't necessary, as there are HTML element equivalents. In this case, {{HTMLElement('code')}} {{HTMLElement('figure')}} and {{HTMLElement('subscript')}}, respectively.

## Best Practices

Do not use.

## Specifications

| Specification                                                                                                                    | Status                                           |
| -------------------------------------------------------------------------------------------------------------------------------- | ------------------------------------------------ |
| {{SpecName("ARIA","#section","ARIA: section role")}}                                             | {{Spec2('ARIA')}}                         |

## See Also

- [ARIA: `structure` role](/en-US/docs/Web/Accessibility/ARIA/Roles/structure_role)
- [ARIA: `alert` role](/en-US/docs/Web/Accessibility/ARIA/Roles/alert_role)
- [ARIA: `associationlist` role](/en-US/docs/Web/Accessibility/ARIA/Roles/associationlist_role)
- [ARIA: `associationlistitemkey` role](/en-US/docs/Web/Accessibility/ARIA/Roles/associationlistitemkey_role)
- [ARIA: `associationlistitemvalue` role](/en-US/docs/Web/Accessibility/ARIA/Roles/associationlistitemvalue_role)
- [ARIA: `blockquote` role](/en-US/docs/Web/Accessibility/ARIA/Roles/blockquote_role)
- [ARIA: `caption` role](/en-US/docs/Web/Accessibility/ARIA/Roles/caption_role)
- [ARIA: `cell` role](/en-US/docs/Web/Accessibility/ARIA/Roles/cell_role)
- [ARIA: `code` role](/en-US/docs/Web/Accessibility/ARIA/Roles/code_role)
- [ARIA: `definition` role](/en-US/docs/Web/Accessibility/ARIA/Roles/definition_role)
- [ARIA: `deletion` role](/en-US/docs/Web/Accessibility/ARIA/Roles/deletion_role)
- [ARIA: `emphasis` role](/en-US/docs/Web/Accessibility/ARIA/Roles/emphasis_role)
- [ARIA: `figure` role](/en-US/docs/Web/Accessibility/ARIA/Roles/figure_role)
- [ARIA: `group` role](/en-US/docs/Web/Accessibility/ARIA/Roles/group_role)
- [ARIA: `img` role](/en-US/docs/Web/Accessibility/ARIA/Roles/img_role)
- [ARIA: `insertion` role](/en-US/docs/Web/Accessibility/ARIA/Roles/insertion_role)
- [ARIA: `landmark` role](/en-US/docs/Web/Accessibility/ARIA/Roles/landmark_role)
- [ARIA: `list` role](/en-US/docs/Web/Accessibility/ARIA/Roles/list_role)
- [ARIA: `listitem` role](/en-US/docs/Web/Accessibility/ARIA/Roles/listitem_role)
- [ARIA: `log` role](/en-US/docs/Web/Accessibility/ARIA/Roles/log_role)
- [ARIA: `mark` role](/en-US/docs/Web/Accessibility/ARIA/Roles/mark_role)
- [ARIA: `marquee` role](/en-US/docs/Web/Accessibility/ARIA/Roles/marquee_role)
- [ARIA: `math` role](/en-US/docs/Web/Accessibility/ARIA/Roles/math_role)
- [ARIA: `note` role](/en-US/docs/Web/Accessibility/ARIA/Roles/note_role)
- [ARIA: `paragraph` role](/en-US/docs/Web/Accessibility/ARIA/Roles/paragraph_role)
- [ARIA: `status` role](/en-US/docs/Web/Accessibility/ARIA/Roles/status_role)
- [ARIA: `strong` role](/en-US/docs/Web/Accessibility/ARIA/Roles/strong_role)
- [ARIA: `subscript` role](/en-US/docs/Web/Accessibility/ARIA/Roles/subscript_role)
- [ARIA: `suggestion` role](/en-US/docs/Web/Accessibility/ARIA/Roles/suggestion_role)
- [ARIA: `superscript` role](/en-US/docs/Web/Accessibility/ARIA/Roles/superscript_role)
- [ARIA: `table` role](/en-US/docs/Web/Accessibility/ARIA/Roles/table_role)
- [ARIA: `tabpanel` role](/en-US/docs/Web/Accessibility/ARIA/Roles/tabpanel_role)
- [ARIA: `term` role](/en-US/docs/Web/Accessibility/ARIA/Roles/term_role)
- [ARIA: `time` role](/en-US/docs/Web/Accessibility/ARIA/Roles/time_role)
- [ARIA: `tooltip` role](/en-US/docs/Web/Accessibility/ARIA/Roles/tooltip_role)

<section id="Quick_links">

1. [**WAI-ARIA roles**](/en-US/docs/Web/Accessibility/ARIA/Roles)

    {{ListSubpagesForSidebar("/en-US/docs/Web/Accessibility/ARIA/Roles")}}

</section>
