---
title: KeyframeEffect.target
slug: Web/API/KeyframeEffect/target
tags:
  - API
  - Animation
  - Experimental
  - KeyframeEffect
  - Property
  - Reference
  - target
  - waapi
  - web animations api
browser-compat: api.KeyframeEffect.target
---
{{ SeeCompatTable() }}{{ APIRef("Web Animations API") }}

The **`target`** property of a {{domxref("KeyframeEffect")}} interface represents the element or pseudo-element being animated. It may be `null` for animations that do not target a specific element. It performs as both a getter and a setter, except with animations and transitions generated by CSS.

## Syntax

```js
var targetElement = document.getElementById("elementToAnimate");

var keyframes = new KeyframeEffect( targetElement, keyframeBlock, timingOptions );

// returns #elementToAnimate
keyframes.target;

// assigns keyframes a new target
keyframes.target = newTargetElement;
```

### Value

An {{domxref("Element")}}, {{domxref("CSSPseudoElement")}}, or `null`.

## Examples

In the [Follow the White Rabbit example](http://codepen.io/rachelnabors/pen/eJyWzm/?editors=0010), `whiteRabbit` sets the **`target`** element to be animated:

```js
var whiteRabbit = document.getElementById("rabbit");

var rabbitDownKeyframes = new KeyframeEffect(
  whiteRabbit,
  [
    { transform: 'translateY(0%)' },
    { transform: 'translateY(100%)' }
  ],
  { duration: 3000, fill: 'forwards' }
);

// returns <div id="rabbit">Click the rabbit's ears!</div>
rabbitDownKeyframes.target;
```

## Specifications

{{Specifications}}

## Browser compatibility

{{Compat}}

## See also

- [Web Animations API](/en-US/docs/Web/API/Web_Animations_API)
- Property of {{domxref("KeyframeEffect")}} objects.
